@@ -76,6 +76,32 @@ class NaceCode:
     nace_type: Literal["VAT", "NSSO", "unknown"] | None = None
 
 
+@dataclass(slots=True)
+class NaceCodeExtended:
+    """
+    Class representing the NACE codes in the `nace_codes` Mongo collection, mainly used for internal testing.
+
+    :param number: The NACE code number.
+    :param description_fr: The French description of the NACE code.
+    :param description_nl: The Dutch description of the NACE code.
+    :param description_en: The English description of the NACE code.
+    :param section_code: The section (one of the 21 high level category) code of the NACE code.
+    :param section_label: The section label of the NACE code.
+    :param version: The NACE version year (2003, 2008, or 2025).
+    :param country: The country code ("BE" for Belgium, "NL" for Netherlands, "FR" for France).
+    """
+
+    number: str
+    level: int
+    description_fr: str | None
+    description_nl: str | None
+    description_en: str | None
+    section_code: str
+    section_label: str
+    version: Literal[2003, 2008, 2025]
+    country: Literal["BE", "NL", "FR"]
+
+
 @dataclass(slots=True)
 class Email:
     email: str
